==> purpose_1.1.orig.tar.xz: purpose-1.1/autotests/alternativesmodeltest.h <==
/************************************************************************************
 * Copyright (C) 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>                *
 *                                                                                  *
 * This program is free software; you can redistribute it and/or                    *
 * modify it under the terms of the GNU General Public License                      *
 * as published by the Free Software Foundation; either version 2                   *
 * of the License, or (at your option) any later version.                           *
 *                                                                                  *
 * This program is distributed in the hope that it will be useful,                  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 * GNU General Public License for more details.                                     *
 *                                                                                  *
 * You should have received a copy of the GNU General Public License                *
 * along with this program; if not, write to the Free Software                      *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 ************************************************************************************/
#ifndef ALTERNATIVESMODELTEST_H
#define ALTERNATIVESMODELTEST_H

#include <QObject>

class AlternativesModelTest : public QObject
{
    Q_OBJECT
    private Q_SLOTS:
        void runJobTest();
        void bigBufferTest();
};

#endif

==> purpose_5.54.0.orig.tar.xz: purpose-5.54.0/autotests/alternativesmodeltest.h <==
/************************************************************************************
 * Copyright (C) 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>                *
 *                                                                                  *
 * This program is free software; you can redistribute it and/or                    *
 * modify it under the terms of the GNU General Public License                      *
 * as published by the Free Software Foundation; either version 2                   *
 * of the License, or (at your option) any later version.                           *
 *                                                                                  *
 * This program is distributed in the hope that it will be useful,                  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 * GNU General Public License for more details.                                     *
 *                                                                                  *
 * You should have received a copy of the GNU General Public License                *
 * along with this program; if not, write to the Free Software                      *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 ************************************************************************************/
#ifndef ALTERNATIVESMODELTEST_H
#define ALTERNATIVESMODELTEST_H

#include <QObject>
#include <QTemporaryDir>

class AlternativesModelTest : public QObject
{
    Q_OBJECT
private Q_SLOTS:
        void initTestCase();
        void runJobTest();
        void bigBufferTest();
        void disablePluginTest();
        void blacklistTest();
private:
    QTemporaryDir m_tempDir;
};

#endif
